<?php
/**
* © Copyright 2007 IntraHealth International, Inc.
* 
* This File is part of I2CE 
* 
* I2CE is free software; you can redistribute it and/or modify 
* it under the terms of the GNU General Public License as published by 
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful, 
* but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License 
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
*  iHRIS_Person
* @package I2CE
* @subpackage Core
* @author Carl Leitner <litlfred@ibiblio.org>
* @copyright Copyright &copy; 2007 IntraHealth International, Inc. 
* This file is part of I2CE. I2CE is free software; you can redistribute it and/or modify it under 
* the terms of the GNU General Public License as published by the Free Software Foundation; either 
* version 3 of the License, or (at your option) any later version. I2CE is distributed in the hope 
* that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have 
* received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
* @version 2.1
* @access public
*/


class iHRIS_Person extends I2CE_Form{


    /**
     * Create a new instance of a person.
     * 
     * @param string $form The name of this form
     * @param integer $id
     */
    public function __construct( $form, $id = 0 ) {                
        parent::__construct( $form, $id );
        $this->ignore_error = false;
    }


    /**
     * Perform additional validation for the Person object.
     * 
     * A new person record needs to verify there aren't any existing records with the same name.
     * @param I2CE_Template $page A reference to the top level Template object
     */
    public function validate( $page ) {
        parent::validate( $page );
        // Search for existing records with the same name.
        $search = array();
        $surname_ignore = false;
        if (array_key_exists('surname_ignore',$this->fields)) {
            $surname_ignore = $this->surname_ignore;
        }
        if ( I2CE_ModuleFactory::instance()->isEnabled('forms-storage') 
             && $this->id == 0 && !$surname_ignore
             && I2CE_Validate::checkString( $this->surname ) 
             && I2CE_Validate::checkString( $this->firstname ) ) {
            $where = array(
                'operator' => 'AND',
                'operand'=>array(
                    0=>array(
                        'operator'=>'FIELD_LIMIT',
                        'field'=>'surname',
                        'style'=>'lowerlike',
                        'data'=>array('value'=>strtolower($this->surname))
                        ),
                    1=>array(
                        'operator'=>'FIELD_LIMIT',
                        'field'=>'firstname',
                        'style'=>'lowerlike',
                        'data'=>array('value'=>strtolower($this->firstname))                        
                        )
                    )
                );
            $results = I2CE_FormStorage::listFields('person',array('surname','firstname'),false,$where,array('surname','firstname'));
            if( count($results) > 0 ) {
                foreach ($results as $id=>&$data) {
                    $data = implode(', ', $data);
                }
                $page->setFormInvalid( $this->getField('surname')->getHTMLName(), "Duplicate records match this record's name:",
                                       array( "view?id=" => $results ) );
            }
        }
        
    }



    /**
     * Search the database for a person record.
     * 
     * Returns a list of records that match the given search parameters.
     * The $search parameter is an array in the following format:
     * array( 
     *  '<form>' => array( 
     *          0 => array( 'field' => '<field_name>', 
     *                  'values' => array( 0 => array( 'value' => '<field_value>', 'method' => '=', 'lower' => <boolean> ) ),
     *                  - or -
     *                  'values' => 'norecord',
     *                  'value_andor' => 'OR',
     *                  'history' => <false|true>
     * )
     * 
     * $andor can be an array.  If it is, the first entry is the default value used.  The 1st entry goes between the 1st two where clauses, etc.
     * 
     * Any forms not matching person will use the parent id from the record entry for the matching results.
     * @param array $search
     * @param string $andor If the search results should be AND or OR among all the search criteria
     * @param boolean $modified
     * @param array $limit The limit to use on the final query, ie: array( 0, 100 ) to start at the beginning
     *                     and return 100 rows.
     * @return array
     */
    static public function search( $search, $andor = "AND", $modified=false, $limit=null ) {
        $where_data = array();
        $order_by = array('surname','firstname');
        $results = I2CE_FormStorage::listFields('person',$order_by,false,$where_data, $order_by,$limit);
        foreach ($results as &$res) {
            $res = $res['surname'] . ", " . $res['firstname'];
        }
        return $results;
    }


}
# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
