<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @package iHRIS
 * @subpackage Manage
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v1.0.0
 * @version v2.0.0
 */
/**
 * Object for dealing with competencies.
 * 
 * @package iHRIS
 * @subpackage Manage
 * @access public
 */
class iHRIS_Competency extends I2CE_List {



    static public function getCompetencyWithType($id) {
        if ($id > 0) {
            return self::getCompetenciesByType(true,$id);
        } else {
            return '';
        }
    }

    /**
     * List all competencies by type (the linked form for this object).
     * 
     * This will return an array that includes all competency types with all competencies
     * that are in that type.
     * @param boolean $flat.  If false. returns array indexed by compentency id, then comptentcy_type name.  Otherwise it returns an array indexed by compenety_type name
     * @param string $id.  Defaults to null. If non-null it is the id of the competency to limit to. in which case we simply return the comptenty_type and and comptenecy name
     * @return array
     */
    static public function getCompetenciesByType($flat = true, $id = null) {
        if ($id !== null) {
            $comp = I2CE_FormStorage::lookupField('competency',$id,array('name','competency_type'),false);
            if (!is_array($comp) || !array_key_exists('name',$comp)) {
                return;
            }
            if (array_key_exists('competency_type',$comp)) {
                $type = I2CE_FormStorage::lookupField('competency_type',$comp['competency_type'],array('name'));
            } else {
                $type = '';
            }
            return $type['name'] . ' = ' . $comp['name'];
        }
        //we have no id set so we need to get all results.
        $ret = array();
        if ($flat) {
            $competencies = I2CE_FormStorage::listFields('competency',array('name','competency_type'));
            $competency_types = I2CE_FormStorage::listFields('competency_type',array('name'));
            foreach ($competency as $id=>$comp) {                
                $val = '';
                if (array_key_exists($comp['competency_type'],$competency_types)) {
                    $val .= $competency_types[$comp['competency_type']]['name'];
                }
                $val .= ' - ' . $comp['name'];
                $ret[$id] = $val;
            }
        } else {
            $competency_types = I2CE_FormStorage::listFields('competency_type',array('name'));
            $where = array(
                'operator' =>'FIELD_LIMIT',
                'field'=>'type',
                'style'=>'equals',
                'data'=>array(
                    'value'=>0
                    )
                );            
            foreach ($comptency_types as $id=>$type) {
                $ret[$id] = array();
                $where['data']['value'] = $id;
                $competencies = I2CE_FormStorage::listFields('competency',array('name') , false,$where);
                foreach ($competencies as $comp_id=>$comp) {
                    $ret[$id][$comp_id] = $type['name'] . ' - ' . $comp['name'];
                }
            }
        }
        return $ret;
    }

}

# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
