<?php
/**
* © Copyright 2008 IntraHealth International, Inc.
* 
* This File is part of I2CE 
* 
* I2CE is free software; you can redistribute it and/or modify 
* it under the terms of the GNU General Public License as published by 
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful, 
* but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License 
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
*  iHRIS_PageForm_Scheduled_Training_Course
* @package I2CE
* @subpackage Core
* @author Carl Leitner <litlfred@ibiblio.org>
* @copyright Copyright &copy; 2008 IntraHealth International, Inc. 
* This file is part of I2CE. I2CE is free software; you can redistribute it and/or modify it under 
* the terms of the GNU General Public License as published by the Free Software Foundation; either 
* version 3 of the License, or (at your option) any later version. I2CE is distributed in the hope 
* that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have 
* received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
* @version 2.1
* @access public
*/


class iHRIS_PageForm_Scheduled_Training_Course extends I2CE_PageForm{

    /**
     * @var integer The record id number of the object being edited.
     */
    protected $id;


    /**
     * @var integer The record id number of the parent of the object being edited.
     */
    protected $course_id;

    /**
     * Create a new instance of this page.
     * 
     * This will call the parent constructor and then setup the base
     * template pages for the {@link I2CE_Template template}.  It also sets up the values
     * for the member variables.
     * @param string $title The title for this page.
     * @param string $defaultHTMLFile The default HTML file for this page.
     * @param mixed $access The role required to access this page.
     * @param array $files The list of template files to load for this page.
     */
    public function __construct( $args,$request_remainder) {
        parent::__construct( $args,$request_remainder);
        $this->id = 'scheduled_training_course';
        $this->course_id = 'training_course';
        if ( $this->isPost() ) {
            if ( $this->post_exists( 'id' ) ) {
                $this->id = $this->post('id');
            }           
            if ( $this->post_exists( 'parent' ) ) {
                $this->course_id = $this->post('parent');
            }
        } else {
            if ( $this->get_exists( 'id' ) ) {
                $this->id = $this->get('id');  
            }
            if ( $this->get_exists( 'parent' ) ) {
                $this->course_id = $this->get('parent');
                //echo "Setting course id to " . $this->course_id;
            }
        }
    }


    /**
     * Create and load data for the objects used for this form.
     * 
     * Create the list object and if this is a form submission load
     * the data from the form data.
     */
    protected function loadObjects() {
        $factory = I2CE_FormFactory::instance();
        $scheduledCourse = $factory->createForm(  $this->id );
        if (!$scheduledCourse instanceof I2CE_Form || !$scheduledCourse->form() == 'training_course') {
            I2CE::raiseError("Bad scheduled training course");
            return false;
        }
        $this->setObject( $scheduledCourse);
        if ($scheduledCourse->getId() != '0') {
            $scheduledCourse->populate();
            $this->course_id =  $scheduledCourse->getParent(true);
        } 
        $parent = $factory->createForm(  $this->course_id );
        if (!$parent instanceof I2CE_Form) {
            I2CE::raiseError("Bad form " . $this->course_id);
            return false;
        }
        $parent->populate();
        $this->setObject( $parent , I2CE_PageForm::EDIT_PARENT );
        parent::loadObjects();
    }

    /**
     * Save the objects to the database.
     * 
     * Save the default object being edited and return to the view page.
     * @global array
     */
    protected function save() {
        parent::save();
        $this->setRedirect(  "view_list?type=training_course&id=" . $this->getParent()->getFormId() );
    }

    protected function action() {
        if ($this->permissionParser->hasTask('can_edit_scheduled_training_course') || $this->permissionParser->hasTask('can_edit_all_database_lists')) {
            parent::action();
        } else {
            $this->userMessage("You do not have permission to add or edit a scheduled training course",'notice');
            $this->setRedirect('noaccess');
        }
    }

    /**
     * Display the save or confirm button templates as needed.
     * @param boolean $save Flag to show the save button.
     * @param boolean $show_edit (defaults to true)
     */
    protected function displayControls( $save = false, $show_edit = true ) {
        if (!$this->getPrimary() instanceof I2CE_Form) {
            return false;
        }
        if ( $save ) {
            $this->template->addFile( "button_save.html" );
        } elseif ( $this->getPrimary()->getId() != '0' ) {
            $node = $this->template->addFile( "button_confirm.html" );     
            $buttonNode = $this->template->getElementById('button_return',$node);
            if ($buttonNode instanceof DOMElement) {
                $buttonNode->setAttribute('href','view_list?mapped=scheduled_training_course&type=training_course&id=' );
            }
        } else {
            $node = $this->template->addFile( "button_save_return.html" );     
            $buttonNode = $this->template->getElementById('button_return',$node);
            if ($buttonNode instanceof DOMElement) {
                $buttonNode->setAttribute('href','view_list?mapped=scheduled_training_course&type=training_course&id=' );
            }
        }
    }



    public function loadHTMLTemplates() {
        if (!$this->getPrimary() instanceof I2CE_Form) {
            return false;
        }
        parent::loadHTMLTemplates();
        $studentListNode = $this->template->getElementById('list_students');
        if (!$studentListNode instanceof DOMNode) {
            $this->template->setDisplayDataImmediate('has_enrolled_students','');
            return;
        }
        $scheduledCourse = $this->getPrimary();
        if (!$scheduledCourse instanceof iHRIS_Scheduled_Training_Course) {
            $this->template->setDisplayDataImmediate('has_enrolled_students','');
            return;
        }
        if ($scheduledCourse->getID() != '0') {
            $this->template->setDisplayDataImmediate('has_enrolled_students','');
            return;
        }
        $personIds = $scheduledCourse->getEnrolledStudents();
        if (count($personIds) == 0) {
            $this->template->setDisplayDataImmediate('has_enrolled_students','');
            return;
        }
        $factory = I2CE_FormFactory::instance();
        $enrolled = false;
        foreach ($personIds as $personID) {
            if ($personID < 1) {
                continue;
            }
            $person = $factory->createForm('person'.'|'.$personID);
            if (!$person instanceof iHRIS_Person) {
                continue;
            }
            $person->populate();
            $personNode = $this->template->appendFileByNode("scheduled_course_list_person.html", 'li',$studentListNode);
            if (!$personNode instanceof DOMNode) {
                continue;
            }
            $enrolled  = true;
            $this->template->setDisplayDataImmediate('person_surname', $person->surname,$personNode);
            $this->template->setDisplayDataImmediate('person_firstname',$person->firstname,$personNode);
            $this->template->setDisplayDataImmediate('person_id','id=person|' .$personID,$personNode);
        }
        if ($enrolled) {
            $this->template->setDisplayDataImmediate('has_enrolled_students','1');
        } else {
            $this->template->setDisplayDataImmediate('has_enrolled_students','');
        }
        
    }


}
# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
