<?php
/**
* © Copyright 2008 IntraHealth International, Inc.
* 
* This File is part of I2CE 
* 
* I2CE is free software; you can redistribute it and/or modify 
* it under the terms of the GNU General Public License as published by 
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful, 
* but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License 
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
*  iHRIS_PageForm_Person_Scheduled_Training_Course
* @package I2CE
* @subpackage Core
* @author Carl Leitner <litlfred@ibiblio.org>
* @copyright Copyright &copy; 2008 IntraHealth International, Inc. 
* This file is part of I2CE. I2CE is free software; you can redistribute it and/or modify it under 
* the terms of the GNU General Public License as published by the Free Software Foundation; either 
* version 3 of the License, or (at your option) any later version. I2CE is distributed in the hope 
* that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have 
* received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
* @version 2.1
* @access public
*/


class iHRIS_PageForm_Evaluate_Course_Competencies extends I2CE_PageForm{

    /**
     * @var integer The record id number of the object being edited. -- the person_scheduled_training_course
     */
    protected $id;


    /**
     * @var integer $person_id
     */
    protected $person_id;

    /**
     * Create a new instance of this page.
     * 
     * This will call the parent constructor and then setup the base
     * template pages for the {@link I2CE_Template template}.  It also sets up the values
     * for the member variables.
     * @param string $title The title for this page.
     * @param string $defaultHTMLFile The default HTML file for this page.
     * @param mixed $access The role required to access this page.
     * @param array $files The list of template files to load for this page.
     */
    public function __construct( $args,$request_remainder) {
        parent::__construct( $args,$request_remainder);
        $this->person_id = false;
        $this->course_id = false;
        if ( $this->isPost() ) {
            if ( $this->post_exists( 'parent' ) ) {
                $this->person_id = $this->post('parent');
            }           
            if ( $this->post_exists( 'id' ) ) {
                $this->id = $this->post('id');
            }
        } else {
            if ( $this->get_exists( 'parent' ) ) {
                $this->person_id = $this->get('parent');
            }
            if ( $this->get_exists( 'id' ) ) {
                $this->id = $this->get('id');
            }
        }
    }

    


    protected $evaluaions;

    /**
     * Create and load data for the objects used for this form.
     * 
     * Create the list object and if this is a form submission load
     * the data from the form data.
     */
    protected function loadObjects() {
        $this->evaluations = array();
        //make sure we have valid objects
        if ($this->id == false) {
            
        } else {
            $personScheduledCourse = $factory->createForm( $this->id );       
            return;
        }
        $factory = I2CE_FormFactory::instance();
        if (!$personScheduledCourse instanceof I2CE_Form) {
            I2CE::raiseError("Cannot instantitatne person scheudled training course " . $this->id);
            return false;
        }
        $personScheduledCourse->populate();
        if (!is_array($personScheduledCourse->scheduled_training_course) || $personScheduledCourse->scheduled_training_course[1] < 1) {
            I2CE::raiseError("No valid training course");
            return;
        }
        $schedCourseForm = $factory->createForm($personScheduledCourse->scheduled_training_course);
        if (!$schedCourseForm instanceof I2CE_Form) {
            return;
        }
        $schedCourseForm->populate();
        echo "Sched Course Form = " . $schedCourseForm->getFormId() . "\n";
        $courseForm = $factory->createForm($schedCourseForm->training_course);
        if (!$courseForm instanceof I2CE_Form) {
            return;
        }
        $courseForm->populate();
        echo " Course Form = " . $courseForm->getFormId() . "\n";

        $this->person_id =  $personScheduledCourse->getParent();
        $parent = $factory->createForm( $personScheduledCourse->getParent());
        if (!$parent instanceof I2CE_Form) {
            return;
        }
        $parent->populate();
        echo "Parent = " . $parent->getFormId()  . "\n";

        $this->setObject( $personScheduledCourse);
        $this->setObject( $parent , I2CE_PageForm::EDIT_PARENT );
        //now we load the competency evaluations which are children of person_scheduled_training_ouse
        $personScheduledCourse->populateChildren('training_course_competency_evaluation');
        $evaluationForms = $personScheduledCourse->getChildren('training_course_competency_evaluation');        
        if (!is_array($evaluationForms)) {
            $evaluationForms = array();
        }
        $t_evaluationForms = array();
        foreach ($evaluationForms as $evaluationForm) {
            if (!is_array($evaluationForm->competency)) {
                continue;
            }
            $t_evaluationForms[$evaluationForm->competency[1]] = $evaluationForm;
        }
        //now get "missing evaluations" and remove dont use any extraneous ones
        $compField = $courseForm->getField('competency');
        if (!$compField instanceof I2CE_FormField_MAP_MULT) {
            I2CE::raiseError("Comptency field for training course is not am MAP_MULT:" . get_class($compField));
            return false;
        }
        foreach ($courseForm->competency as $competencyData) {
            if (!is_array($competencyData) || count($competencyData) != 2) {
                continue;
            }
            $competencyID = $competencyData[1];
            if ($competencyID == '0' ) {
                continue;
            }
            $competencyForm = $factory->createForm($competencyData);
            if (!$competencyForm instanceof I2CE_Form) {
                continue;
            }
            $competencyForm->populate();
            if (array_key_exists($competencyID,$t_evaluationForms)) {
                echo "Existing $competencyID\n";
                $evaluationForm = $t_evaluationForms[$competencyID];
                $evaluationForm->populate();
                $this->evaluations[$competencyID] = $evaluationForm;
            } else {
                echo "Creating $competencyID\n";
                $evaluationForm = $factory->createForm('training_course_competency_evaluation');
                if (!$evaluationForm instanceof I2CE_Form) {
                    continue;
                }
                $evaluationForm->evaluation_date = I2CE_Date::now();
                $evaluationForm->competency = $competencyID;
                $evaluationForm->competency_type = $competencyForm->competency_type;
                $evaluationForm->competency_evalution = 'competency_evaluation|not_evaluated';
                $evaluationForm->setParent($this->id);
                $evaluationForm->save($this->user);
                $this->evaluations[$competencyID] = $evaluationForm;
            }
            $evaluationNode = $this->template->loadFile("training_course_evaluation_form.html",'span');
            if (!$evaluationNode instanceof DOMElement) {
                I2CE::raiseError("Unable to add evaluation node");
                return false;
            }
            $this->template->setDisplayDataImmediate('competency_name',$competencyForm->name,$evaluationNode);
            $this->evaluation_nodes[$competencyID] = $evaluationNode;
            $evaluationNode->setAttribute('id',$evaluationForm->getFormId());
            $this->setObject($evaluationForm,I2CE_PageForm::EDIT_CHILD, $evaluationForm->getFormId());                        
        }
        //now reorder evaluations by the name of the competency
        ksort($this->evaluations, SORT_LOCALE_STRING);
        parent::loadObjects();
    }




    /**
     * Save the objects to the database.
     * 
     * Save the default object being edited and return to the view page.
     * @global array
     */
    protected function save() {
        //now set the evaluation objects
        $factory = I2CE_FormFactory::instance();
        $parent = $this->getParent();
        if (!$parent instanceof I2CE_Form) {
            I2CE::raiseError("Cannot save evalautions b/c no person is set");
            return false;
        }
        $parent->populateChildren('person_competency');
        $t_persComps = $parent->getChildren('person_competency');
        $persComps = array();
        foreach ($t_persComps as $persComp) {
            $persComps[$persComp->competency] = $persComp;
        }
        foreach ($this->evaluations as $evaluationForm) {
            $evaluationForm->save($this->user);
            //we also need to copy the comptencies over to a person_competency if the evaluation date is not set or earlier
            $eval_date = $evaluationForm->getField('evaluation_date');
            if (!$eval_date instanceof I2CE_FormField || !$eval_date->issetValue()) {
                I2Ce::raiseError("Could not get evaluation date for training competency");
                continue; //shouldn't happen.  being paranoid.
            }
            if (!array_key_exists($evaluationForm->competency,$persComps)) {
                //competency does not exist for the person, 
                $persComp = $factory->createForm('person_competency');
                $persComp->setParent($this->person_id);
                foreach (array('competency','competency_type') as $key) {
                    $persComp->$key = $evaluationForm->$key;
                }
                $persComps[$evaluationForm->competency] = $persComp; //don't really need to do this.  just in case we have a corruption of a repeated competency type
            } else {
                //competency does exist for the person, 
                $persComp = $persComps[$evaluationForm->competency];
            }
            $pers_eval_date = $persComp->getField('evaluation_date');            
            if (!$pers_eval_date instanceof I2CE_FormField) {
                I2CE::raiseError("Could not get evaluation date for person competency:" . get_class($pers_eval_date));
                continue; //shouldn't happen.  being paranoid.
            }
            if ($pers_eval_date->issetValue()) {
                $pers_eval_date =  $pers_eval_date->getValue();
                if ($pers_eval_date instanceof I2CE_Date && $pers_eval_date->isValid() && $pers_eval_date->compare($eval_date->getValue()) == -1) { 
                    //there is a evaluation date attached to the personal competency and it is after the evlation date for the training competency                
                    continue;
                }
            }
            //we need to update the personal evalation
            $persComp->evaluation_date = $evaluationForm->evaluation_date;
            $persComp->competency_evaluation = $evaluationForm->competency_evaluation;
            $persComp->save($this->user);            
        }
        parent::save();        
        $this->setRedirect( "view?id=" . $this->getParent()->getFormId() );
    }

    /**
     * Run the validation methods for all the objects being edited.
     * 
     * If this is a form submit then run the validation methods for the default object being edited.  The default method
     * calls the {@link I2CE_Form::validate() validate} method on the {@link $edit_obj} object.
     */
    protected function validate() {
        if ( $this->isPost() ) {
            foreach ($this->evaluations as $evaluationForm) {
                echo "BADDNESS in iHRISpgaeform evaluate couse comps\n";
                //$evaluationForm->load($this->post,$evaluationForm->getId(), false);
                $evaluationForm->validate( $this->template );
            }
        }
        parent::validate();
    }
    /**
     * Load the  template (HTML or XML) files to the template object.
     *  
     * 
     */  
    protected function loadHTMLTemplates() {
        parent::loadHTMLTemplates();
        $evaluationsNode = $this->template->getElementById('list_evaluations');
        if (!$evaluationsNode instanceof DOMNode) {
            I2CE::raiseError("Don't know where to list evaluations");
            return false;
        }
        foreach ($this->evaluations as $id=>$evaluationForm) {
            $evaluationNode = $this->evaluation_nodes[$id];
            $evaluationsNode->appendChild($evaluationNode);
            //$this->template->addPostfixToFormElements($evaluationForm->getId(),$evaluationNode);                
        }
        
    }
    


    /**
     * Display the save or confirm button templates as needed.
     * @param boolean $save Flag to show the save button.
     * @param boolean $show_edit (defaults to true)
     */
    protected function displayControls( $save = false, $show_edit = true ) {
        if ( $save ) {
            $this->template->addFile( "button_save.html" );
        } else {
            $this->template->addFile( "button_confirm.html" );     
        }
    }
                


}
# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
